# Notes
# This script analyses data from the Ntungamo_Kawanda trial.
# To navigate the code use the scrip outline right next to "source" icon

#Inputs-----
file_Kawanda_Ntugamo_in <- "./Nutrition_and_weevils/data/processed/2_Nutrient_ommision_trials.csv"

# Outputs----

# Tables
table_out_1   <- "./Nutrition_and_weevils/results/tables/5_N+fP+K+Insecticide+fOther_nutrients.csv"
table_out_2   <- "./Nutrition_and_weevils/results/tables/5_N+fP+K+Insecticide+fOther_nutrients_disp.csv"

#Figures
Fig_1 <- "./results/figures/5_"

# Import----
dat <- fread(file_Kawanda_Ntugamo_in)
glimpse(dat)
dat <- dat %>% filter(XT < 50) %>% 
  mutate_if(is.character,factor) %>% 
  mutate(fK = as.factor(K),
         fN = as.factor(N),
         fP = as.factor(P),
         fOther_nutrients = as.factor(Other_nutrients),
         fCycle = as.factor(Cycle))

# Inference----
# All treatments----
levels(dat$labels)

#### Interactive----
# trts X Cycle interaction is not significant
dat$Trts <- relevel(dat$Trts, "0K_0N_0P_0Ot_0SP")
mm1 <- glmmTMB(XT ~ Cycle*Trts+(1|Block/Plot/Mat),
               family = nbinom2, data=dat)
summary(mm1)

#break trts and do interactions
mm1b <- glmmTMB(XT ~ Cycle*(N+P+K+Insecticide+Other_nutrients)+
                  (1|Block/Plot/Mat),
               family = nbinom2, data=dat)
summary(mm1b)

#### Additive----
# The model cant pick up the effects of other treatments
mm2 <- glmmTMB(XT ~ Cycle+Trts+(1|Block/Plot/Mat),
               family = nbinom2, data=dat)
summary(mm2)

# Take Cycle to the dispersion model ( Brooks et al 2017)
mm2b <- glmmTMB(XT ~ Trts+(1|Block/Plot/Mat),disp=~Cycle,
                family = nbinom2, data=dat)
summary(mm2b)

# Break up the plots into treatments
mm2c <- glmmTMB(XT ~ N+P+K+Insecticide+Other_nutrients+(1|Block/Plot/Mat),
                disp=~Cycle,
                family = nbinom2, data=dat)
summary(mm2c)

# bring cycle in the fixed part of the model
mm2d <- glmmTMB(XT ~ Cycle+N+P+K+Insecticide+Other_nutrients+(1|Block/Plot/Mat),
                family = nbinom2, data=dat)
summary(mm2d)

# represent all nutrients as factors
mm2e <- glmmTMB(XT ~ fN+fP+fK+Insecticide+fOther_nutrients+(1|Block/Plot/Mat),
                disp=~Cycle,
                family = nbinom2, data=dat)

summary(mm2e)

# represent K and N as continuous 
mm2eii <- glmmTMB(XT ~ N+fP+K+Insecticide+fOther_nutrients+(1|Block/Plot/Mat),
                  disp=~Cycle,family = nbinom2, data=dat)

summary(mm2eii)

mm2eiii <- glmmTMB(XT ~ N+fP+K+Insecticide+fOther_nutrients+(1|Block/Plot/Mat),
                  disp=~fCycle,family = nbinom2, data=dat)

summary(mm2eiii)

##### AIC comparison----
AICtab(mm1,mm1b, mm2,mm2b,mm2c,mm2d,mm2e,mm2eii,mm2eiii)

# mm2eii and mm2c
anova(mm2c,mm2eii)

# Refit the final model using REML
mm2eii_reml <- glmmTMB(XT ~ N+fP+K+Insecticide+fOther_nutrients+(1|Block/Plot/Mat),
                  disp=~Cycle,REML = TRUE, family = nbinom2, data=dat)

summary(mm2eii_reml)

# look at dispersion factor
disp <- testDispersion(mm2eii) %>% tidy() %>%
  .[1,1]; disp  # close to one

# look at the residuals
simulationOutput <- DHARMa::simulateResiduals(fittedModel = mm2eii, plot = F)
plotQQunif(simulationOutput)
testOutliers(mm2eii, type = "bootstrap")
testZeroInflation(mm2eii)

## Check intercept model with full model----
# intercept only
mm2eii_null1 <- glmmTMB(XT ~1+
                          (1|Block/Plot/Mat),disp=~Cycle,
                        family = nbinom2, data=dat)
summary(mm2eii_null1)

# anova
anova(mm2eii_null1,mm2eii)

# Refit the final model using REML
mm2eii_reml <- glmmTMB(XT ~ N+fP+K+Insecticide+fOther_nutrients+
                         (1|Block/Plot/Mat),disp=~Cycle,
                       REML = TRUE, family = nbinom2, data=dat)

summary(mm2eii_reml)
# save tables
# fixed model table_out_1
broom.mixed::tidy(mm2eii_reml) %>%
  fwrite(., table_out_1)

# disp model table_out_1b
tabl <- summary(mm2eii_reml)
tabl <- tabl$coefficients$disp %>% tibble()
fwrite(tabl, table_out_2)

#plots----
## mm2eii----
dat$XT_p <- predict(mm2eii, newdata=dat, allow.new.levels = TRUE,
                    type = 'response')
# plot the prediction vs the observed
form <- summary(mm2eii)
plot_name <- gsub(" ", "",  as.character(formula(mm2eii, fixed.only = TRUE)[3]))
g_mm2eii <- ggplot(data = dat, aes(x = XT_p, y = XT, color = fCycle))+
  geom_point()+
  geom_smooth(method = "lm")+
  facet_wrap(facets = "fCycle")+
  geom_abline(intercept = 0, slope = 1)+
  ggtitle("Ntungamo Kawanda trial")+
  labs(y = "Observed weevil damage (%)",
       x = "Predicted weevil damage (%)",
       caption = as.character(as.expression(form$call)))+
  theme_custom()+
  theme(plot.caption=element_text(hjust = .5, vjust = 0.2))+
  scale_colour_custom(name = "Cycles")
g_mm2eii

ggsave(plot = g_mm2eii, filename =  paste0(Fig_1,plot_name, ".tiff"),
       dpi = 600, width = 10, height = 7)

